function [ h ] = plot_matrices( matrices, n, m )
%PLOT_MATRICES Plots a set of matrices as a subplot of size n, m
%   
% PARAMETERS
%
% matrices          An array of structs, each containing:
%
%                   matrix - the matrix to plot
%                   color_map - the colour map (default = 'jet')
%                   limits - the colour map limits (default = matrix range)
%                   title - the title for the subplot

% If n and m are not defined, calculate 2 x N
N = length(matrices);
if nargin < 2
   n = 2;
   m = int32(ceil(N / 2));
end

h=figure;
set(gcf,'Color','w');
for i = 1 : N
   
    matrx = matrices(i);
    g = subplot(n,m,i);
    clear opt; opt.color_map =  'jet';
    if isfield(matrx,'color_map'),  opt.color_map = matrx.color_map; end
    if isfield(matrx,'limits'),  opt.limits = matrx.limits; end
    opt.flag_bar=false;
    %opt.flag_square=false;
    
    niak_visu_matrix(matrx.matrix,opt);
    set(gca,'xtick',[])
    set(gca,'ytick',[])
    
    if isfield(matrx,'title'),  title(matrx.title); end
    
    % Enlarge
    p = get(g,'position');
    p(1) = p(1) - 0.05;   % Shift left 10% of screen
    p(2) = p(2) - 0.05;   % Shift down 10% of screen
    p(3) = p(3)*1.10; % Add 30 percent to width
    p(4) = p(4)*1.10; % Add 30 percent to height
    set(g, 'position', p);
    
     %g = colorbar;
%     p = get(g,'position');
%     %p(2) = p(2)-0.1;   % Shift down 10% of screen
%     p(3) = p(3)*1.30; % Add 30 percent to width
%     p(4) = p(4)*1.30; % Add 30 percent to height
%     set(g, 'position', p);
    
    freezeColors;
    %cbfreeze;
    
end

end

