function [ G, M, idx ] = threshold_by_sparsity( M, sparsity )

%THRESHOLD_BY_SPARSITY Thresholds a vector M such that the
% resulting graph has the given SPARSITY (as a proportion from 0 to 1); or 
% at least a sparsity closest to this value without arbitraily removing
% identical values. For example, if many values are similar around the
% threshold level, none or all of these values are thresholded (determined
% by the 'smaller' argument).
% 
% PARAMETERS:
%   M           An N x 1 vector, 
%   SPARSITY    The desired sparsity, as a proportion from 0 (no edges) to
%               1 (all edges).
%
% RETURNS:
%   A binarized graph G where G(i,j)= 1 indicates the existence of an edge 
%   between vertices i and j.
%

N = length(M);
K = round(sparsity*N);  

[M_sort M_ind] = sort(M, 'descend');      % Sort elements
val = M_sort(K);
if val > 0
    G = M >= val;
else
    G = M > val;
end

M = M.*double(G);
idx = find(G);

end

