function [ D P ] = z_comparison (R1, R2, N1, N2)

% Compares correlation matrices R1 and R2, given a sample size of N1; 
% uneven sample sizes can be indicated by defining N2. 
% Convertsthe R values to Z values (Fisher's transform) and 
% compares the difference to the normal distribution.
%
% PARAMETERS:
% 
% R1, R2        - The correlation matrices
% N1            - The sample size
% N2            - The sample size for R2 if different from N1
%
% OUTPUT:
% 
% D             - The difference as a z-score (R1-R2)
% P             - The two-tailed p-values associated with D
%
% AUTHOR: Andrew Reid, MNI, 2012
%

% Fisher transform
R1_Z = atanh(R1);
R2_Z = atanh(R2);

if ~exist('N2','var')
   N2=N1; 
end

% Get deltas
D = R1_Z.*sqrt(N1-3) - R2_Z.*sqrt(N2-3);
%D = D.*sqrt(N-3);

% Get significance
%P = abs(D) > normpdf(threshold);
P = 2 * normpdf(abs(D));

